@@ -6,9 +6,11 @@ import qualified Test.QuickCheck.Simple as QSimple
 import Lex (eqProp, eqProp')
 import Model
 
-import Data.Int (Int32, Int64)
 import Control.Arrow (returnA, arr, (<<<), (***))
-import Database.Relational.Query.Arrow
+import Data.Int (Int32, Int64)
+import Data.Functor.ProductIsomorphic ((|$|), (|*|))
+
+import Database.Relational.Arrow
 
 tables :: [Test]
 tables =
@@ -278,9 +280,9 @@ _p_nested :: IO ()
 _p_nested =  mapM_ print [show nestedPiRec, show nestedPiCol, show nestedPi]
 
 
--- Projection Operators
+-- Record Operators
 
-bin53 :: (Projection Flat Int32 -> Projection Flat Int32 -> Projection Flat r) -> Relation () r
+bin53 :: (Record Flat Int32 -> Record Flat Int32 -> Record Flat r) -> Relation () r
 bin53 op = relation $ proc () -> do
   returnA -< value 5 `op` value 3
 
@@ -288,7 +290,7 @@ strIn :: Relation () (Maybe Bool)
 strIn = relation $ proc () -> do
   returnA -< value "foo" `in'` values ["foo", "bar"]
 
-boolTF :: (Projection Flat (Maybe Bool) -> Projection Flat (Maybe Bool) -> Projection Flat r) -> Relation () r
+boolTF :: (Record Flat (Maybe Bool) -> Record Flat (Maybe Bool) -> Record Flat r) -> Relation () r
 boolTF op = relation $ proc () -> do
   returnA -< valueTrue `op` valueFalse
 
@@ -300,7 +302,7 @@ strLike :: Relation () (Maybe Bool)
 strLike = relation $ proc () -> do
   returnA -< value "Hoge" `like` "H%"
 
-_p_bin53 :: (Projection Flat Int32 -> Projection Flat Int32 -> Projection Flat r) -> IO ()
+_p_bin53 :: (Record Flat Int32 -> Record Flat Int32 -> Record Flat r) -> IO ()
 _p_bin53 = print . bin53
 
 bin :: [Test]
